"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Channel(google.protobuf.message.Message):
    """Root entity for content separation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the channel."""
    organization_id: builtins.str
    """ID of the organization where channel should be created."""
    title: builtins.str
    """Channel title."""
    description: builtins.str
    """Channel description."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when channel was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last channel update."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def settings(self) -> global___ChannelSettings:
        """Channel settings."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: global___ChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "settings", b"settings", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "id", b"id", "labels", b"labels", "organization_id", b"organization_id", "settings", b"settings", "title", b"title", "updated_at", b"updated_at"]) -> None: ...

global___Channel = Channel

@typing.final
class ChannelSettings(google.protobuf.message.Message):
    """Channel settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVERTISEMENT_FIELD_NUMBER: builtins.int
    REFERER_VERIFICATION_FIELD_NUMBER: builtins.int
    @property
    def advertisement(self) -> global___AdvertisementSettings:
        """Advertisement settings."""

    @property
    def referer_verification(self) -> global___RefererVerificationSettings:
        """Referer verification settings"""

    def __init__(
        self,
        *,
        advertisement: global___AdvertisementSettings | None = ...,
        referer_verification: global___RefererVerificationSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["advertisement", b"advertisement", "referer_verification", b"referer_verification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advertisement", b"advertisement", "referer_verification", b"referer_verification"]) -> None: ...

global___ChannelSettings = ChannelSettings

@typing.final
class AdvertisementSettings(google.protobuf.message.Message):
    """Advertisement settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class YandexDirect(google.protobuf.message.Message):
        """YandexDirect provider settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLE_FIELD_NUMBER: builtins.int
        PAGE_ID_FIELD_NUMBER: builtins.int
        CATEGORY_FIELD_NUMBER: builtins.int
        enable: builtins.bool
        """Enable Partner Ad for Live and VOD content."""
        page_id: builtins.int
        """Advertisement page ID."""
        category: builtins.int
        """Advertisement category."""
        def __init__(
            self,
            *,
            enable: builtins.bool = ...,
            page_id: builtins.int = ...,
            category: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["category", b"category", "enable", b"enable", "page_id", b"page_id"]) -> None: ...

    YANDEX_DIRECT_FIELD_NUMBER: builtins.int
    @property
    def yandex_direct(self) -> global___AdvertisementSettings.YandexDirect: ...
    def __init__(
        self,
        *,
        yandex_direct: global___AdvertisementSettings.YandexDirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["provider", b"provider", "yandex_direct", b"yandex_direct"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["provider", b"provider", "yandex_direct", b"yandex_direct"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["provider", b"provider"]) -> typing.Literal["yandex_direct"] | None: ...

global___AdvertisementSettings = AdvertisementSettings

@typing.final
class RefererVerificationSettings(google.protobuf.message.Message):
    """Referer verification settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    ALLOWED_DOMAINS_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    """Enable verification"""
    @property
    def allowed_domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of available domains"""

    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        allowed_domains: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allowed_domains", b"allowed_domains", "enable", b"enable"]) -> None: ...

global___RefererVerificationSettings = RefererVerificationSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.clickhouse.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.clickhouse.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.clickhouse.v1.config import clickhouse_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_config_dot_clickhouse__pb2
from yandex.cloud.mdb.clickhouse.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_database__pb2
from yandex.cloud.mdb.clickhouse.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.clickhouse.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/clickhouse/v1/cluster_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a+yandex/cloud/mdb/clickhouse/v1/backup.proto\x1a,yandex/cloud/mdb/clickhouse/v1/cluster.proto\x1a\x36yandex/cloud/mdb/clickhouse/v1/config/clickhouse.proto\x1a-yandex/cloud/mdb/clickhouse/v1/database.proto\x1a\x30yandex/cloud/mdb/clickhouse/v1/maintenance.proto\x1a)yandex/cloud/mdb/clickhouse/v1/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"j\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.clickhouse.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xeb\x07\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.clickhouse.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12N\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.clickhouse.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x45\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12L\n\x0e\x64\x61tabase_specs\x18\x07 \x03(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.DatabaseSpecB\x06\x82\xc8\x31\x02>0\x12\x44\n\nuser_specs\x18\x08 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.UserSpecB\x06\x82\xc8\x31\x02>0\x12\x44\n\nhost_specs\x18\t \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\nshard_name\x18\x0b \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12M\n\x12maintenance_window\x18\x0f \x01(\x0b\x32\x31.yandex.cloud.mdb.clickhouse.v1.MaintenanceWindow\x12>\n\x0bshard_specs\x18\x10 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.ShardSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xf5\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.mdb.clickhouse.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12?\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12M\n\x12maintenance_window\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.mdb.clickhouse.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\t \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12\x1c\n\nnetwork_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"\xfc\x01\n\x1a\x41\x64\x64\x43lusterZookeeperRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\x12<\n\nhost_specs\x18\x03 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.HostSpec\x12@\n\x1c\x63onvert_tables_to_replicated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"1\n\x1b\x41\x64\x64\x43lusterZookeeperMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x94\x06\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x15\x61\x64\x64itional_backup_ids\x18\r \x03(\t\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x41.yandex.cloud.mdb.clickhouse.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12N\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.mdb.clickhouse.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12\x45\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12\x44\n\nhost_specs\x18\x07 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12\x1a\n\x12security_group_ids\x18\x0b \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12>\n\x0bshard_specs\x18\x0f \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.ShardSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0c\x10\r\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\xcf\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12j\n\x0freschedule_type\x18\x02 \x01(\x0e\x32K.yandex.cloud.mdb.clickhouse.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"\xb3\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x07message\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.mdb.clickhouse.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x03\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12^\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x42.yandex.cloud.mdb.clickhouse.v1.ListClusterLogsRequest.ServiceTypeB\x04\xe8\xc7\x31\x01\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\";\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCLICKHOUSE\x10\x01\"k\n\x17ListClusterLogsResponse\x12\x37\n\x04logs\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x0fStreamLogRecord\x12\x39\n\x06record\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\x8b\x03\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12`\n\x0cservice_type\x18\x03 \x01(\x0e\x32\x44.yandex.cloud.mdb.clickhouse.v1.StreamClusterLogsRequest.ServiceTypeB\x04\xe8\xc7\x31\x01\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\";\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCLICKHOUSE\x10\x01\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1aListClusterBackupsResponse\x12\x37\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.clickhouse.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"h\n\x18ListClusterHostsResponse\x12\x33\n\x05hosts\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.clickhouse.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb1\x01\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\nhost_specs\x18\x02 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12/\n\x0b\x63opy_schema\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\x90\x01\n\x0eUpdateHostSpec\x12\x17\n\thost_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x10\x61ssign_public_ip\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x90\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Q\n\x11update_host_specs\x18\x02 \x03(\x0b\x32..yandex.cloud.mdb.clickhouse.v1.UpdateHostSpecB\x06\x82\xc8\x31\x02>0\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"c\n\x1aRestartClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=353\"E\n\x1bRestartClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"n\n\x16GetClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"z\n\x18ListClusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x19ListClusterShardsResponse\x12\x35\n\x06shards\x18\x01 \x03(\x0b\x32%.yandex.cloud.mdb.clickhouse.v1.Shard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xab\x02\n\x16\x41\x64\x64\x43lusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x44\n\x0b\x63onfig_spec\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.clickhouse.v1.ShardConfigSpec\x12\x44\n\nhost_specs\x18\x04 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12/\n\x0b\x63opy_schema\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"A\n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"\xf2\x01\n\x17\x41\x64\x64\x43lusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x0bshard_specs\x18\x02 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.ShardSpecB\x06\x82\xc8\x31\x02>0\x12<\n\nhost_specs\x18\x03 \x03(\x0b\x32(.yandex.cloud.mdb.clickhouse.v1.HostSpec\x12/\n\x0b\x63opy_schema\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"C\n\x18\x41\x64\x64\x43lusterShardsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x13\n\x0bshard_names\x18\x02 \x03(\t\"\xe8\x01\n\x19UpdateClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x44\n\x0b\x63onfig_spec\x18\x04 \x01(\x0b\x32/.yandex.cloud.mdb.clickhouse.v1.ShardConfigSpec\"D\n\x1aUpdateClusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"q\n\x19\x44\x65leteClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"D\n\x1a\x44\x65leteClusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"u\n\x1a\x44\x65leteClusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bshard_names\x18\x02 \x03(\tB \xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x82\xc8\x31\x02>0\x8a\xc8\x31\x04<=63\"F\n\x1b\x44\x65leteClusterShardsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x13\n\x0bshard_names\x18\x02 \x03(\t\"y\n\x1bGetClusterShardGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x10shard_group_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"\x7f\n\x1dListClusterShardGroupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"{\n\x1eListClusterShardGroupsResponse\x12@\n\x0cshard_groups\x18\x01 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.ShardGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x01\n\x1e\x43reateClusterShardGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x10shard_group_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0bshard_names\x18\x04 \x03(\t\"O\n\x1f\x43reateClusterShardGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10shard_group_name\x18\x02 \x01(\t\"\xd7\x01\n\x1eUpdateClusterShardGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x10shard_group_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0bshard_names\x18\x05 \x03(\t\"O\n\x1fUpdateClusterShardGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10shard_group_name\x18\x02 \x01(\t\"|\n\x1e\x44\x65leteClusterShardGroupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x10shard_group_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"O\n\x1f\x44\x65leteClusterShardGroupMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10shard_group_name\x18\x02 \x01(\t\"\x88\x01\n&ListClusterExternalDictionariesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xad\x01\n\'ListClusterExternalDictionariesResponse\x12i\n\x15\x65xternal_dictionaries\x18\x01 \x03(\x0b\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb3\x01\n&CreateClusterExternalDictionaryRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12g\n\x13\x65xternal_dictionary\x18\x02 \x01(\x0b\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary\"=\n\'CreateClusterExternalDictionaryMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xe4\x01\n&UpdateClusterExternalDictionaryRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12g\n\x13\x65xternal_dictionary\x18\x02 \x01(\x0b\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"_\n\'UpdateClusterExternalDictionaryMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12 \n\x18\x65xternal_dictionary_name\x18\x02 \x01(\t\"l\n&DeleteClusterExternalDictionaryRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x18\x65xternal_dictionary_name\x18\x02 \x01(\t\"=\n\'DeleteClusterExternalDictionaryMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xcb\x01\n\x08HostSpec\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12=\n\x04type\x18\x02 \x01(\x0e\x32).yandex.cloud.mdb.clickhouse.v1.Host.TypeB\x04\xe8\xc7\x31\x01\x12\x1b\n\tsubnet_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x61ssign_public_ip\x18\x04 \x01(\x08\x12.\n\nshard_name\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"\xc7\x06\n\nConfigSpec\x12\x0f\n\x07version\x18\x03 \x01(\t\x12I\n\nclickhouse\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.clickhouse.v1.ConfigSpec.Clickhouse\x12G\n\tzookeeper\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.clickhouse.v1.ConfigSpec.Zookeeper\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32&.yandex.cloud.mdb.clickhouse.v1.Access\x12\x43\n\rcloud_storage\x18\x06 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.CloudStorage\x12;\n\x17sql_database_management\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13sql_user_management\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x61\x64min_password\x18\t \x01(\t\x12\x33\n\x0f\x65mbedded_keeper\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x19\x62\x61\x63kup_retain_period_days\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x93\x01\n\nClickhouse\x12G\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\x1aI\n\tZookeeper\x12<\n\tresources\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\"\xa4\x02\n\x0fShardConfigSpec\x12N\n\nclickhouse\x18\x01 \x01(\x0b\x32:.yandex.cloud.mdb.clickhouse.v1.ShardConfigSpec.Clickhouse\x1a\xc0\x01\n\nClickhouse\x12G\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\x12+\n\x06weight\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x9a\x01\n\tShardSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x44\n\x0b\x63onfig_spec\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.clickhouse.v1.ShardConfigSpec\x12\x19\n\x11shard_group_names\x18\x03 \x03(\t2\xd8>\n\x0e\x43lusterService\x12\x97\x01\n\x03Get\x12\x31.yandex.cloud.mdb.clickhouse.v1.GetClusterRequest\x1a\'.yandex.cloud.mdb.clickhouse.v1.Cluster\"4\x82\xd3\xe4\x93\x02.\x12,/managed-clickhouse/v1/clusters/{cluster_id}\x12\x9a\x01\n\x04List\x12\x33.yandex.cloud.mdb.clickhouse.v1.ListClustersRequest\x1a\x34.yandex.cloud.mdb.clickhouse.v1.ListClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-clickhouse/v1/clusters\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.clickhouse.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02$\"\x1f/managed-clickhouse/v1/clusters:\x01*\x12\xbe\x01\n\x06Update\x12\x34.yandex.cloud.mdb.clickhouse.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\x32,/managed-clickhouse/v1/clusters/{cluster_id}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.clickhouse.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/managed-clickhouse/v1/clusters/{cluster_id}\x12\xbe\x01\n\x05Start\x12\x33.yandex.cloud.mdb.clickhouse.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x34\"2/managed-clickhouse/v1/clusters/{cluster_id}:start\x12\xba\x01\n\x04Stop\x12\x32.yandex.cloud.mdb.clickhouse.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-clickhouse/v1/clusters/{cluster_id}:stop\x12\xbd\x01\n\x04Move\x12\x32.yandex.cloud.mdb.clickhouse.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x36\"1/managed-clickhouse/v1/clusters/{cluster_id}:move:\x01*\x12\xdd\x01\n\x0c\x41\x64\x64Zookeeper\x12:.yandex.cloud.mdb.clickhouse.v1.AddClusterZookeeperRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*&\n\x1b\x41\x64\x64\x43lusterZookeeperMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02>\"9/managed-clickhouse/v1/clusters/{cluster_id}:addZookeeper:\x01*\x12\xc2\x01\n\x06\x42\x61\x63kup\x12\x34.yandex.cloud.mdb.clickhouse.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x35\"3/managed-clickhouse/v1/clusters/{cluster_id}:backup\x12\xbc\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.clickhouse.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/managed-clickhouse/v1/clusters:restore:\x01*\x12\xf3\x01\n\x15RescheduleMaintenance\x12<.yandex.cloud.mdb.clickhouse.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02G\"B/managed-clickhouse/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xb6\x01\n\x08ListLogs\x12\x36.yandex.cloud.mdb.clickhouse.v1.ListClusterLogsRequest\x1a\x37.yandex.cloud.mdb.clickhouse.v1.ListClusterLogsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-clickhouse/v1/clusters/{cluster_id}:logs\x12\xbb\x01\n\nStreamLogs\x12\x38.yandex.cloud.mdb.clickhouse.v1.StreamClusterLogsRequest\x1a/.yandex.cloud.mdb.clickhouse.v1.StreamLogRecord\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-clickhouse/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xce\x01\n\x0eListOperations\x12<.yandex.cloud.mdb.clickhouse.v1.ListClusterOperationsRequest\x1a=.yandex.cloud.mdb.clickhouse.v1.ListClusterOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-clickhouse/v1/clusters/{cluster_id}/operations\x12\xc2\x01\n\x0bListBackups\x12\x39.yandex.cloud.mdb.clickhouse.v1.ListClusterBackupsRequest\x1a:.yandex.cloud.mdb.clickhouse.v1.ListClusterBackupsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-clickhouse/v1/clusters/{cluster_id}/backups\x12\xba\x01\n\tListHosts\x12\x37.yandex.cloud.mdb.clickhouse.v1.ListClusterHostsRequest\x1a\x38.yandex.cloud.mdb.clickhouse.v1.ListClusterHostsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-clickhouse/v1/clusters/{cluster_id}/hosts\x12\xe4\x01\n\x08\x41\x64\x64Hosts\x12\x36.yandex.cloud.mdb.clickhouse.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-clickhouse/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xee\x01\n\x0bUpdateHosts\x12\x39.yandex.cloud.mdb.clickhouse.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-clickhouse/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*\x12\xee\x01\n\x0b\x44\x65leteHosts\x12\x39.yandex.cloud.mdb.clickhouse.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\">/managed-clickhouse/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\x12\xf2\x01\n\x0cRestartHosts\x12:.yandex.cloud.mdb.clickhouse.v1.RestartClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*4\n\x1bRestartClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/managed-clickhouse/v1/clusters/{cluster_id}/hosts:restartHosts:\x01*\x12\xb3\x01\n\x08GetShard\x12\x36.yandex.cloud.mdb.clickhouse.v1.GetClusterShardRequest\x1a%.yandex.cloud.mdb.clickhouse.v1.Shard\"H\x82\xd3\xe4\x93\x02\x42\x12@/managed-clickhouse/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xbe\x01\n\nListShards\x12\x38.yandex.cloud.mdb.clickhouse.v1.ListClusterShardsRequest\x1a\x39.yandex.cloud.mdb.clickhouse.v1.ListClusterShardsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/managed-clickhouse/v1/clusters/{cluster_id}/shards\x12\xc9\x01\n\x08\x41\x64\x64Shard\x12\x36.yandex.cloud.mdb.clickhouse.v1.AddClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2* \n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x05Shard\x82\xd3\xe4\x93\x02\x38\"3/managed-clickhouse/v1/clusters/{cluster_id}/shards:\x01*\x12\xd9\x01\n\tAddShards\x12\x37.yandex.cloud.mdb.clickhouse.v1.AddClusterShardsRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*\"\n\x18\x41\x64\x64\x43lusterShardsMetadata\x12\x06Shards\x82\xd3\xe4\x93\x02\x44\"?/managed-clickhouse/v1/clusters/{cluster_id}/shards:batchCreate:\x01*\x12\xdf\x01\n\x0bUpdateShard\x12\x39.yandex.cloud.mdb.clickhouse.v1.UpdateClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*#\n\x1aUpdateClusterShardMetadata\x12\x05Shard\x82\xd3\xe4\x93\x02\x45\x32@/managed-clickhouse/v1/clusters/{cluster_id}/shards/{shard_name}:\x01*\x12\xec\x01\n\x0b\x44\x65leteShard\x12\x39.yandex.cloud.mdb.clickhouse.v1.DeleteClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*3\n\x1a\x44\x65leteClusterShardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42*@/managed-clickhouse/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xf2\x01\n\x0c\x44\x65leteShards\x12:.yandex.cloud.mdb.clickhouse.v1.DeleteClusterShardsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*4\n\x1b\x44\x65leteClusterShardsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/managed-clickhouse/v1/clusters/{cluster_id}/shards:batchDelete:\x01*\x12\xcd\x01\n\rGetShardGroup\x12;.yandex.cloud.mdb.clickhouse.v1.GetClusterShardGroupRequest\x1a*.yandex.cloud.mdb.clickhouse.v1.ShardGroup\"S\x82\xd3\xe4\x93\x02M\x12K/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups/{shard_group_name}\x12\xd2\x01\n\x0fListShardGroups\x12=.yandex.cloud.mdb.clickhouse.v1.ListClusterShardGroupsRequest\x1a>.yandex.cloud.mdb.clickhouse.v1.ListClusterShardGroupsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups\x12\xeb\x01\n\x10\x43reateShardGroup\x12>.yandex.cloud.mdb.clickhouse.v1.CreateClusterShardGroupRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*-\n\x1f\x43reateClusterShardGroupMetadata\x12\nShardGroup\x82\xd3\xe4\x93\x02=\"8/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups:\x01*\x12\xff\x01\n\x10UpdateShardGroup\x12>.yandex.cloud.mdb.clickhouse.v1.UpdateClusterShardGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x87\x01\xb2\xd2*-\n\x1fUpdateClusterShardGroupMetadata\x12\nShardGroup\x82\xd3\xe4\x93\x02P2K/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups/{shard_group_name}:\x01*\x12\x87\x02\n\x10\x44\x65leteShardGroup\x12>.yandex.cloud.mdb.clickhouse.v1.DeleteClusterShardGroupRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*8\n\x1f\x44\x65leteClusterShardGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02M*K/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups/{shard_group_name}\x12\xf6\x01\n\x18ListExternalDictionaries\x12\x46.yandex.cloud.mdb.clickhouse.v1.ListClusterExternalDictionariesRequest\x1aG.yandex.cloud.mdb.clickhouse.v1.ListClusterExternalDictionariesResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/managed-clickhouse/v1/clusters/{cluster_id}/externalDictionaries\x12\x8e\x02\n\x18\x43reateExternalDictionary\x12\x46.yandex.cloud.mdb.clickhouse.v1.CreateClusterExternalDictionaryRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*2\n\'CreateClusterExternalDictionaryMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02J\"E/managed-clickhouse/v1/clusters/{cluster_id}:createExternalDictionary:\x01*\x12\x8e\x02\n\x18UpdateExternalDictionary\x12\x46.yandex.cloud.mdb.clickhouse.v1.UpdateClusterExternalDictionaryRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*2\n\'UpdateClusterExternalDictionaryMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02J\"E/managed-clickhouse/v1/clusters/{cluster_id}:updateExternalDictionary:\x01*\x12\x8e\x02\n\x18\x44\x65leteExternalDictionary\x12\x46.yandex.cloud.mdb.clickhouse.v1.DeleteClusterExternalDictionaryRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*2\n\'DeleteClusterExternalDictionaryMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02J\"E/managed-clickhouse/v1/clusters/{cluster_id}:deleteExternalDictionary:\x01*Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['database_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['database_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERZOOKEEPERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERZOOKEEPERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['service_type']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['service_type']._serialized_options = b'\350\3071\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['service_type']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['service_type']._serialized_options = b'\350\3071\001'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._loaded_options = None
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _globals['_RESTARTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESTARTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTARTCLUSTERHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_RESTARTCLUSTERHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=353'
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_ADDCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERSHARDSREQUEST'].fields_by_name['shard_specs']._loaded_options = None
  _globals['_ADDCLUSTERSHARDSREQUEST'].fields_by_name['shard_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_UPDATECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_UPDATECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DELETECLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERSHARDSREQUEST'].fields_by_name['shard_names']._loaded_options = None
  _globals['_DELETECLUSTERSHARDSREQUEST'].fields_by_name['shard_names']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\202\3101\002>0\212\3101\004<=63'
  _globals['_GETCLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._loaded_options = None
  _globals['_GETCLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATECLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._loaded_options = None
  _globals['_CREATECLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._loaded_options = None
  _globals['_UPDATECLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DELETECLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERSHARDGROUPREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._loaded_options = None
  _globals['_DELETECLUSTERSHARDGROUPREQUEST'].fields_by_name['shard_group_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATECLUSTEREXTERNALDICTIONARYREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTEREXTERNALDICTIONARYREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTEREXTERNALDICTIONARYREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTEREXTERNALDICTIONARYREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTEREXTERNALDICTIONARYREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTEREXTERNALDICTIONARYREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['subnet_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_SHARDSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_SHARDSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/managed-clickhouse/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-clickhouse/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002$\"\037/managed-clickhouse/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00212,/managed-clickhouse/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/managed-clickhouse/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0024\"2/managed-clickhouse/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-clickhouse/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0026\"1/managed-clickhouse/v1/clusters/{cluster_id}:move:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddZookeeper']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddZookeeper']._serialized_options = b'\262\322*&\n\033AddClusterZookeeperMetadata\022\007Cluster\202\323\344\223\002>\"9/managed-clickhouse/v1/clusters/{cluster_id}:addZookeeper:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0025\"3/managed-clickhouse/v1/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/managed-clickhouse/v1/clusters:restore:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002G\"B/managed-clickhouse/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\0023\0221/managed-clickhouse/v1/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\002:\0228/managed-clickhouse/v1/clusters/{cluster_id}:stream_logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/managed-clickhouse/v1/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0026\0224/managed-clickhouse/v1/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\0024\0222/managed-clickhouse/v1/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-clickhouse/v1/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-clickhouse/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C\">/managed-clickhouse/v1/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RestartHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RestartHosts']._serialized_options = b'\262\322*4\n\033RestartClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/managed-clickhouse/v1/clusters/{cluster_id}/hosts:restartHosts:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShard']._serialized_options = b'\202\323\344\223\002B\022@/managed-clickhouse/v1/clusters/{cluster_id}/shards/{shard_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShards']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShards']._serialized_options = b'\202\323\344\223\0025\0223/managed-clickhouse/v1/clusters/{cluster_id}/shards'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShard']._serialized_options = b'\262\322* \n\027AddClusterShardMetadata\022\005Shard\202\323\344\223\0028\"3/managed-clickhouse/v1/clusters/{cluster_id}/shards:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShards']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShards']._serialized_options = b'\262\322*\"\n\030AddClusterShardsMetadata\022\006Shards\202\323\344\223\002D\"?/managed-clickhouse/v1/clusters/{cluster_id}/shards:batchCreate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateShard']._serialized_options = b'\262\322*#\n\032UpdateClusterShardMetadata\022\005Shard\202\323\344\223\002E2@/managed-clickhouse/v1/clusters/{cluster_id}/shards/{shard_name}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShard']._serialized_options = b'\262\322*3\n\032DeleteClusterShardMetadata\022\025google.protobuf.Empty\202\323\344\223\002B*@/managed-clickhouse/v1/clusters/{cluster_id}/shards/{shard_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShards']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShards']._serialized_options = b'\262\322*4\n\033DeleteClusterShardsMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/managed-clickhouse/v1/clusters/{cluster_id}/shards:batchDelete:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShardGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShardGroup']._serialized_options = b'\202\323\344\223\002M\022K/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups/{shard_group_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShardGroups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShardGroups']._serialized_options = b'\202\323\344\223\002:\0228/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups'
  _globals['_CLUSTERSERVICE'].methods_by_name['CreateShardGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['CreateShardGroup']._serialized_options = b'\262\322*-\n\037CreateClusterShardGroupMetadata\022\nShardGroup\202\323\344\223\002=\"8/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateShardGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateShardGroup']._serialized_options = b'\262\322*-\n\037UpdateClusterShardGroupMetadata\022\nShardGroup\202\323\344\223\002P2K/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups/{shard_group_name}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShardGroup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShardGroup']._serialized_options = b'\262\322*8\n\037DeleteClusterShardGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002M*K/managed-clickhouse/v1/clusters/{cluster_id}/shardGroups/{shard_group_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListExternalDictionaries']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListExternalDictionaries']._serialized_options = b'\202\323\344\223\002C\022A/managed-clickhouse/v1/clusters/{cluster_id}/externalDictionaries'
  _globals['_CLUSTERSERVICE'].methods_by_name['CreateExternalDictionary']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['CreateExternalDictionary']._serialized_options = b'\262\322*2\n\'CreateClusterExternalDictionaryMetadata\022\007Cluster\202\323\344\223\002J\"E/managed-clickhouse/v1/clusters/{cluster_id}:createExternalDictionary:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateExternalDictionary']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateExternalDictionary']._serialized_options = b'\262\322*2\n\'UpdateClusterExternalDictionaryMetadata\022\007Cluster\202\323\344\223\002J\"E/managed-clickhouse/v1/clusters/{cluster_id}:updateExternalDictionary:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteExternalDictionary']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteExternalDictionary']._serialized_options = b'\262\322*2\n\'DeleteClusterExternalDictionaryMetadata\022\007Cluster\202\323\344\223\002J\"E/managed-clickhouse/v1/clusters/{cluster_id}:deleteExternalDictionary:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=638
  _globals['_GETCLUSTERREQUEST']._serialized_end=691
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=694
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=838
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=840
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=946
  _globals['_CREATECLUSTERREQUEST']._serialized_start=949
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1952
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1907
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1952
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1954
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1997
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2000
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2629
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1907
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1952
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2631
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2674
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2676
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2732
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2734
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2777
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2779
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2834
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2836
  _globals['_STARTCLUSTERMETADATA']._serialized_end=2878
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2880
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2934
  _globals['_STOPCLUSTERMETADATA']._serialized_start=2936
  _globals['_STOPCLUSTERMETADATA']._serialized_end=2977
  _globals['_MOVECLUSTERREQUEST']._serialized_start=2979
  _globals['_MOVECLUSTERREQUEST']._serialized_end=3078
  _globals['_MOVECLUSTERMETADATA']._serialized_start=3080
  _globals['_MOVECLUSTERMETADATA']._serialized_end=3178
  _globals['_ADDCLUSTERZOOKEEPERREQUEST']._serialized_start=3181
  _globals['_ADDCLUSTERZOOKEEPERREQUEST']._serialized_end=3433
  _globals['_ADDCLUSTERZOOKEEPERMETADATA']._serialized_start=3435
  _globals['_ADDCLUSTERZOOKEEPERMETADATA']._serialized_end=3484
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=3486
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=3542
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=3544
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=3587
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=3590
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=4378
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=1907
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=1952
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=4380
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=4443
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=4446
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=4781
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=4671
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=4781
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=4783
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=4891
  _globals['_LOGRECORD']._serialized_start=4894
  _globals['_LOGRECORD']._serialized_end=5073
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=5027
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=5073
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=5076
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=5468
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5409
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5468
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=5470
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=5577
  _globals['_STREAMLOGRECORD']._serialized_start=5579
  _globals['_STREAMLOGRECORD']._serialized_end=5682
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=5685
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=6080
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5409
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5468
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=6082
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=6208
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=6210
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=6321
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=6323
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=6446
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=6448
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=6558
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=6560
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=6681
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=6683
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=6787
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=6790
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=6967
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=6969
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=7034
  _globals['_UPDATEHOSTSPEC']._serialized_start=7037
  _globals['_UPDATEHOSTSPEC']._serialized_end=7181
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=7184
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=7328
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=7330
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=7398
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=7400
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=7498
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=7500
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=7568
  _globals['_RESTARTCLUSTERHOSTSREQUEST']._serialized_start=7570
  _globals['_RESTARTCLUSTERHOSTSREQUEST']._serialized_end=7669
  _globals['_RESTARTCLUSTERHOSTSMETADATA']._serialized_start=7671
  _globals['_RESTARTCLUSTERHOSTSMETADATA']._serialized_end=7740
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_start=7742
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_end=7852
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_start=7854
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_end=7976
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_start=7978
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_end=8085
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_start=8088
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_end=8387
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_start=8389
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_end=8454
  _globals['_ADDCLUSTERSHARDSREQUEST']._serialized_start=8457
  _globals['_ADDCLUSTERSHARDSREQUEST']._serialized_end=8699
  _globals['_ADDCLUSTERSHARDSMETADATA']._serialized_start=8701
  _globals['_ADDCLUSTERSHARDSMETADATA']._serialized_end=8768
  _globals['_UPDATECLUSTERSHARDREQUEST']._serialized_start=8771
  _globals['_UPDATECLUSTERSHARDREQUEST']._serialized_end=9003
  _globals['_UPDATECLUSTERSHARDMETADATA']._serialized_start=9005
  _globals['_UPDATECLUSTERSHARDMETADATA']._serialized_end=9073
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_start=9075
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_end=9188
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_start=9190
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_end=9258
  _globals['_DELETECLUSTERSHARDSREQUEST']._serialized_start=9260
  _globals['_DELETECLUSTERSHARDSREQUEST']._serialized_end=9377
  _globals['_DELETECLUSTERSHARDSMETADATA']._serialized_start=9379
  _globals['_DELETECLUSTERSHARDSMETADATA']._serialized_end=9449
  _globals['_GETCLUSTERSHARDGROUPREQUEST']._serialized_start=9451
  _globals['_GETCLUSTERSHARDGROUPREQUEST']._serialized_end=9572
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST']._serialized_start=9574
  _globals['_LISTCLUSTERSHARDGROUPSREQUEST']._serialized_end=9701
  _globals['_LISTCLUSTERSHARDGROUPSRESPONSE']._serialized_start=9703
  _globals['_LISTCLUSTERSHARDGROUPSRESPONSE']._serialized_end=9826
  _globals['_CREATECLUSTERSHARDGROUPREQUEST']._serialized_start=9829
  _globals['_CREATECLUSTERSHARDGROUPREQUEST']._serialized_end=9995
  _globals['_CREATECLUSTERSHARDGROUPMETADATA']._serialized_start=9997
  _globals['_CREATECLUSTERSHARDGROUPMETADATA']._serialized_end=10076
  _globals['_UPDATECLUSTERSHARDGROUPREQUEST']._serialized_start=10079
  _globals['_UPDATECLUSTERSHARDGROUPREQUEST']._serialized_end=10294
  _globals['_UPDATECLUSTERSHARDGROUPMETADATA']._serialized_start=10296
  _globals['_UPDATECLUSTERSHARDGROUPMETADATA']._serialized_end=10375
  _globals['_DELETECLUSTERSHARDGROUPREQUEST']._serialized_start=10377
  _globals['_DELETECLUSTERSHARDGROUPREQUEST']._serialized_end=10501
  _globals['_DELETECLUSTERSHARDGROUPMETADATA']._serialized_start=10503
  _globals['_DELETECLUSTERSHARDGROUPMETADATA']._serialized_end=10582
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST']._serialized_start=10585
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESREQUEST']._serialized_end=10721
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESRESPONSE']._serialized_start=10724
  _globals['_LISTCLUSTEREXTERNALDICTIONARIESRESPONSE']._serialized_end=10897
  _globals['_CREATECLUSTEREXTERNALDICTIONARYREQUEST']._serialized_start=10900
  _globals['_CREATECLUSTEREXTERNALDICTIONARYREQUEST']._serialized_end=11079
  _globals['_CREATECLUSTEREXTERNALDICTIONARYMETADATA']._serialized_start=11081
  _globals['_CREATECLUSTEREXTERNALDICTIONARYMETADATA']._serialized_end=11142
  _globals['_UPDATECLUSTEREXTERNALDICTIONARYREQUEST']._serialized_start=11145
  _globals['_UPDATECLUSTEREXTERNALDICTIONARYREQUEST']._serialized_end=11373
  _globals['_UPDATECLUSTEREXTERNALDICTIONARYMETADATA']._serialized_start=11375
  _globals['_UPDATECLUSTEREXTERNALDICTIONARYMETADATA']._serialized_end=11470
  _globals['_DELETECLUSTEREXTERNALDICTIONARYREQUEST']._serialized_start=11472
  _globals['_DELETECLUSTEREXTERNALDICTIONARYREQUEST']._serialized_end=11580
  _globals['_DELETECLUSTEREXTERNALDICTIONARYMETADATA']._serialized_start=11582
  _globals['_DELETECLUSTEREXTERNALDICTIONARYMETADATA']._serialized_end=11643
  _globals['_HOSTSPEC']._serialized_start=11646
  _globals['_HOSTSPEC']._serialized_end=11849
  _globals['_CONFIGSPEC']._serialized_start=11852
  _globals['_CONFIGSPEC']._serialized_end=12691
  _globals['_CONFIGSPEC_CLICKHOUSE']._serialized_start=12469
  _globals['_CONFIGSPEC_CLICKHOUSE']._serialized_end=12616
  _globals['_CONFIGSPEC_ZOOKEEPER']._serialized_start=12618
  _globals['_CONFIGSPEC_ZOOKEEPER']._serialized_end=12691
  _globals['_SHARDCONFIGSPEC']._serialized_start=12694
  _globals['_SHARDCONFIGSPEC']._serialized_end=12986
  _globals['_SHARDCONFIGSPEC_CLICKHOUSE']._serialized_start=12794
  _globals['_SHARDCONFIGSPEC_CLICKHOUSE']._serialized_end=12986
  _globals['_SHARDSPEC']._serialized_start=12989
  _globals['_SHARDSPEC']._serialized_end=13143
  _globals['_CLUSTERSERVICE']._serialized_start=13146
  _globals['_CLUSTERSERVICE']._serialized_end=21170
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.translate.v2.translation_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TranslationServiceStub:
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Translate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateRequest,
        yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateResponse,
    ]
    """Translates the text to the specified language."""

    DetectLanguage: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageRequest,
        yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageResponse,
    ]
    """Detects the language of the text."""

    ListLanguages: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesRequest,
        yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesResponse,
    ]
    """Retrieves the list of supported languages."""

class TranslationServiceAsyncStub:
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    Translate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateRequest,
        yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateResponse,
    ]
    """Translates the text to the specified language."""

    DetectLanguage: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageRequest,
        yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageResponse,
    ]
    """Detects the language of the text."""

    ListLanguages: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesRequest,
        yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesResponse,
    ]
    """Retrieves the list of supported languages."""

class TranslationServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    @abc.abstractmethod
    def Translate(
        self,
        request: yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateResponse, collections.abc.Awaitable[yandex.cloud.ai.translate.v2.translation_service_pb2.TranslateResponse]]:
        """Translates the text to the specified language."""

    @abc.abstractmethod
    def DetectLanguage(
        self,
        request: yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageResponse, collections.abc.Awaitable[yandex.cloud.ai.translate.v2.translation_service_pb2.DetectLanguageResponse]]:
        """Detects the language of the text."""

    @abc.abstractmethod
    def ListLanguages(
        self,
        request: yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesResponse, collections.abc.Awaitable[yandex.cloud.ai.translate.v2.translation_service_pb2.ListLanguagesResponse]]:
        """Retrieves the list of supported languages."""

def add_TranslationServiceServicer_to_server(servicer: TranslationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TransceiverType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TransceiverTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TransceiverType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRANSCEIVER_TYPE_UNSPECIFIED: _TransceiverType.ValueType  # 0
    TRANSCEIVER_TYPE_1000BASE_LX: _TransceiverType.ValueType  # 1
    TRANSCEIVER_TYPE_10GBASE_LR: _TransceiverType.ValueType  # 2
    TRANSCEIVER_TYPE_10GBASE_ER: _TransceiverType.ValueType  # 3
    TRANSCEIVER_TYPE_100GBASE_LR4: _TransceiverType.ValueType  # 4
    TRANSCEIVER_TYPE_100GBASE_ER4: _TransceiverType.ValueType  # 5

class TransceiverType(_TransceiverType, metaclass=_TransceiverTypeEnumTypeWrapper): ...

TRANSCEIVER_TYPE_UNSPECIFIED: TransceiverType.ValueType  # 0
TRANSCEIVER_TYPE_1000BASE_LX: TransceiverType.ValueType  # 1
TRANSCEIVER_TYPE_10GBASE_LR: TransceiverType.ValueType  # 2
TRANSCEIVER_TYPE_10GBASE_ER: TransceiverType.ValueType  # 3
TRANSCEIVER_TYPE_100GBASE_LR4: TransceiverType.ValueType  # 4
TRANSCEIVER_TYPE_100GBASE_ER4: TransceiverType.ValueType  # 5
global___TransceiverType = TransceiverType



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ImageGenerationAsyncServiceStub:
    """Service for creating images based on a text description."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Generate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_service_pb2.ImageGenerationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """A method for generating an image based on a textual description."""

class ImageGenerationAsyncServiceAsyncStub:
    """Service for creating images based on a text description."""

    Generate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_service_pb2.ImageGenerationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """A method for generating an image based on a textual description."""

class ImageGenerationAsyncServiceServicer(metaclass=abc.ABCMeta):
    """Service for creating images based on a text description."""

    @abc.abstractmethod
    def Generate(
        self,
        request: yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_service_pb2.ImageGenerationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """A method for generating an image based on a textual description."""

def add_ImageGenerationAsyncServiceServicer_to_server(servicer: ImageGenerationAsyncServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
